@@ -70,7 +70,7 @@ class System:
         """"""
         ip_address = subprocess.check_output(["hostname", "-I"]).split()[0].decode()
         try:
-            with open("/var/lib/tor/main/hostname") as fp:
+            with open("/home/gaea/app/run/onion") as fp:
                 onion = fp.read()
         except FileNotFoundError:
             onion = None
